@@ -1,7 +1,4 @@
 #include "cpphutils.h"
-#include <Rcpp.h>
-using namespace Rcpp;
-#include <omp.h>
 
 constexpr bool ON_TWOS_COMPLEMENT = (-1 == ~0);
 
@@ -10,7 +7,9 @@ LogicalVector do_divisible(IntegerVector x, int d, int nThread = 1) {
   R_xlen_t N = x.length();
   LogicalVector out = no_init(N);
 
+#if defined _OPENMP && _OPENMP >= 201511
 #pragma omp parallel for num_threads(nThread)
+#endif
   for (R_xlen_t i = 0; i < N; ++i) {
     out[i] = !(x[i] % d);
   }
@@ -27,7 +26,9 @@ LogicalVector do_divisible2(IntegerVector x, int nThread = 1) {
   // # nocov end
 
   LogicalVector out = no_init(N);
+#if defined _OPENMP && _OPENMP >= 201511
 #pragma omp parallel for num_threads(nThread) schedule(static)
+#endif
   for (R_xlen_t i = 0; i < N; ++i) {
     uint_fast32_t ui = (uint_fast32_t)x[i];
     out[i] = !(ui & 1U);
@@ -40,7 +41,9 @@ LogicalVector do_divisible16(IntegerVector x, int nThread = 1) {
   R_xlen_t N = x.length();
   LogicalVector out = no_init(N);
 
+#if defined _OPENMP && _OPENMP >= 201511
 #pragma omp parallel for num_threads(nThread)
+#endif
   for (R_xlen_t i = 0; i < N; ++i) {
     unsigned int xi = (unsigned int)x[i];
     out[i] = !(xi % 16);
